/**
 * copyright (c) 2017-2021 厦门风领科技有限公司
 * http://www.fengling.cn/
 * 
 * 适配层
 * zengbinsi
 * 2020-08-15 10:08:05
 */



 window.fl = window.fl || {};
 fl.adapter = fl.adapter || {};

 // 进行平台判断
 (function () {
   
     // 平台枚举
     fl.EPlatformType = {
         MINI_GAME_WX: 'MINI_GAME_WX', // 微信小游戏
         MINI_GAME_TT: 'MINI_GAME_TT', // 字节小游戏
         MINI_GAME_QQ: 'MINI_GAME_QQ', // QQ小游戏
         MINI_GAME_OPPO: 'MINI_GAME_OPPO', // OPPO小游戏
         MINI_GAME_VIVO: 'MINI_GAME_VIVO', // VIVO小游戏
 
         H5: 'H5',
         NATIVE: 'NATIVE',
     };
 
     fl.platform = fl.EPlatformType.MINI_GAME_WX;
     fl.adapter = window.wx || {};
     
     if (window.qq) {
         fl.platform = fl.EPlatformType.MINI_GAME_QQ;
         fl.adapter = window.qq;
     } else if (window.tt) {
         fl.platform = fl.EPlatformType.MINI_GAME_TT;
         fl.adapter = window.tt;
     } else if (window.qg && cc.sys.platform !== cc.sys.VIVO_GAME) {
         fl.platform = fl.EPlatformType.MINI_GAME_OPPO;
         fl.adapter = window.qg;
     } else if (window.qg) {
         fl.platform = fl.EPlatformType.MINI_GAME_VIVO;
         fl.adapter = window.qg;
     } else if (cc.sys.isBrowser) {
         fl.platform = fl.EPlatformType.H5;
     } else if (window.wx) {
         fl.platform = fl.EPlatformType.MINI_GAME_WX;
         fl.adapter = window.wx;
     } else if (cc.sys.isNative) {
         fl.platform = fl.EPlatformType.NATIVE;
     }
     fl.platform = fl.EPlatformType.NATIVE;
     fl.adapter.isMiniGameWX = fl.platform === fl.EPlatformType.MINI_GAME_WX;
     fl.adapter.isMiniGameQQ = fl.platform === fl.EPlatformType.MINI_GAME_QQ;
     fl.adapter.isMiniGameTT = fl.platform === fl.EPlatformType.MINI_GAME_TT;
     fl.adapter.isMiniGameOPPO = fl.platform === fl.EPlatformType.MINI_GAME_OPPO;
     fl.adapter.isMiniGameVIVO = fl.platform === fl.EPlatformType.MINI_GAME_VIVO;
 
     fl.adapter.isH5 = fl.platform === fl.EPlatformType.H5;
     fl.adapter.isNative = fl.platform === fl.EPlatformType.NATIVE;
 })();
 
 
 // 基础函数
 (function () {
     fl._log = console.log;
 
     fl.log = (...params) => {
         return fl._log('fl.framework ===>>>', ...params);
     };
     fl.warn = (...params) => {
         return cc.warn('fl.framework ===>>>', ...params);
     };
 
     fl.logCallStack = () => {
         return fl.log(new Error().stack);
     };
 
     window._gameStartTime = Math.floor(Date.now() / 1000);
     /** 游戏开始时间 */
     fl.gameStartTime = () => {
         return fl._gameStartTime;
     }
     /** 游戏运行时长 */
     fl.getRunTime = () => {
         return Math.floor(Date.now() / 1000) - fl._gameStartTime;
     }
 
     /** 框架版本号 */
     fl.version = '3.1.1';
 
     fl._audioClips = [];
 
     /**
      * 是否是空值（null|undefined）
      * @param value 要判空的值
      */
     fl.isEmpty = (value) => {
         return (value === undefined || value === null);
     }
 
     /**
      * 是否是空值（null|undefined|空字符串）
      * @param value 要判空的值
      */
     fl.isEmptyString = (value) => {
         return (fl.isEmpty(value) || value === '');
     };
 
     /**
      * 如果对象为null或者undefined就返回第二个参数的值
      * @param value 要判空的值
      * @param defaultValue 默认返回值
      */
     fl.ifnull = (value, defaultValue) => {
         if (value === undefined || value === null) {
             return defaultValue;
         } else {
             return value;
         }
     }
 })();
 
 
 (function () {
     /** 文字国际化转换 */
     fl.i18nString = (zhString) => {
         return zhString;
     };
 
     /** 显示系统吐司提示 */
     fl.showToast = (content, duration = 1.5) => {
         if (fl.adapter.isMiniGameVIVO) {
             duration = duration > 1.5 ? 1 : 0;
         } else {
             duration *= 1000;
         }
 
         fl.adapter.showToast({
             title: fl.i18nString(content),
             duration: duration,
         });
     };
 })();
 
 (function () {
     /*=========监听游戏事件========='*/
 
     // 游戏显示，使用这个事件我们可以监听游戏在Native平台上从后台被唤醒的事件，从而对游戏进行一些必要的处理。
     if (cc.game && cc.game.on) {
         cc.game.on(cc.game.EVENT_SHOW, (data) => {
             if (cc.systemEvent && cc.systemEvent.emit) {
                 cc.systemEvent.emit(cc.game.EVENT_SHOW, data);
             }
         });
     }
 
 
     // 当游戏被挂起到后台时，Creator会分发游戏隐藏事件
     if (cc.game && cc.game.on) {
         cc.game.on(cc.game.EVENT_HIDE, (data) => {
             if (cc.systemEvent && cc.systemEvent.emit) {
                 cc.systemEvent.emit(cc.game.EVENT_HIDE, data);
             }
         });
     }
 
 
     // 游戏初始化完成
     if (cc.game && cc.game.on) {
         cc.game.on(cc.game.EVENT_ENGINE_INITED, (data) => {
             if (cc.systemEvent && cc.systemEvent.emit) {
                 cc.systemEvent.emit(cc.game.EVENT_ENGINE_INITED, data);
             }
         });
     }
 
 
     // 如果需要在渲染初始化完成时实现逻辑，可以通过EVENT_RENDERER_INITED事件来实现。
     if (cc.game && cc.game.on) {
         cc.game.on(cc.game.EVENT_RENDERER_INITED, (data) => {
             if (cc.systemEvent && cc.systemEvent.emit) {
                 cc.systemEvent.emit(cc.game.EVENT_RENDERER_INITED, data);
             }
         });
     }
 })();